# Governance Policy

This document delineates the governance policy for the Project. By appending their name to the [maintainers.md file](./maintainers.md), maintainers signify their consent to this policy and commit to observing all Project policies, including the [code of conduct](./policies/code-of-conduct.md).

## 1. Roles

The Project encompasses several roles, defined below. The Project reserves the right to introduce new roles and document them accordingly.

### 1.1. Maintainers
Maintainers are tasked with orchestrating the development, upkeep, and enhancement of the Project. They are also charged with achieving consensus among contributors. The Project can appoint or dismiss Maintainers based on the current Maintainers' consent.

Additionally, Maintainers play a critical role in shaping the future of the platform through **[Architecture Decision Records (ADRs)](../notes/adrs)**. ADRs document key design decisions and proposals, guiding the technical evolution of the Project. Maintainers are responsible for reviewing, discussing, and approving ADRs in collaboration with Contributors.

### 1.2. Contributors
Contributors include individuals who have contributed to the Project, including submitting proposals, code, and feedback on ADRs. Contributors are encouraged to engage with the ADR process, as it offers a structured way to influence and guide the direction of the Project.

## 2. Decisions

### 2.1. Consensus-Based Decision Making
The Project relies on the consensus of the Maintainers for decision-making. While unanimous agreement is preferred, it is not mandatory for consensus. Instead, Maintainers will reach consensus based on a thoughtful evaluation of several factors, including the predominant perspective of the Contributors and the nature of support and objections. Maintainers are responsible for documenting evidence of consensus.

The ADR process plays a key role in decision-making, as it ensures that major technical changes or enhancements are discussed transparently and with broad participation. Each ADR is subject to consensus and formal review by the Maintainers.

### 2.2. Appeal Process
Decisions can be appealed by initiating an issue. Maintainers will review the appeal in good faith and issue a written response promptly. Should the Maintainers reject the appeal, it may be escalated to the Organization Steering Committee, which will also provide a written response in a timely manner.

## 3. Operational Principles

### 3.1. Openness
Participation is open to all individuals directly and materially impacted by the activity in question, without undue financial barriers. This openness extends to the ADR process, where all Contributors can review, propose, and discuss key decisions.

### 3.2. Balance
The development process aims to balance the interests of Contributors and other stakeholders, endeavoring to achieve a diverse representation of Contributors across different interest categories. The ADR process is instrumental in maintaining this balance by ensuring all voices are heard during important architectural discussions.

### 3.3. Coordination and Harmonization
Efforts will be made in good faith to address potential conflicts or inconsistencies between releases in this Project. ADRs serve as the primary method for documenting these efforts and ensuring harmonization across the platform’s evolution.

### 3.4. Consideration of Views and Objections
All Contributors' written views and objections will receive prompt consideration, particularly in the context of ADR discussions, where technical feedback is crucial.

### 3.5. Written Procedures
Documentation of this governance policy and other procedural materials of this project shall be accessible to any interested party. The ADR process itself is fully documented, with clear procedures for submitting and reviewing proposals.

## 4. Transparency of Information

Information disclosed during any Project activity, including meetings, contributions, submissions, and ADR discussions, is not confidential, notwithstanding any contrary markings or statements. This transparency ensures all stakeholders have access to the full context of the Project's technical decisions.

## 5. Trademarks

The Project's names, trademarks, logos, and associated goodwill ("Marks") are governed by the Organization. Maintainers are permitted to use these Marks solely in accordance with the Organization's trademark policy. Rights to the Marks held by a Maintainer who resigns or is removed revert to the Organization.

## 6. Amendments

This governance policy can be amended through a two-thirds majority vote of all Maintainers, subject to approval by the Organization's Steering Committee. Amendments related to architectural decisions are documented and enacted through the ADR process to ensure alignment with the Project's long-term goals.

## Colophon

*Based on the MVG created by GitHub and licensed under the CC-BY 4.0 License.*
